from .stream_gears import *
from .pyobject import Segment, Credit

__all__ = ['Segment', 'Credit']
__doc__ = stream_gears.__doc__
if hasattr(stream_gears, "__all__"):
    __all__.extend(stream_gears.__all__)



import stream_gears

if __name__ == '__main__':
    stream_gears.upload(
        ["examples/test.mp4"],
        "cookies.json",
        "title",
        171,
        "tag",
        1,
        "source",
        "desc",
        "dynamic",
        "",
        0,
        0,
        0,
        0,
        3,
        [],
        None,
        stream_gears.UploadLine.Bda2,
    )

    stream_gears.upload_by_app(
        ["examples/test.mp4",
         "examples/test2.mp4"],
        "cookies.json",
        "dadad",
        171,
        "演示",
        1,
        "",
        "",
        "",
        "",
        0,
        0,
        0,
        0,
        True,
        False,
        False,
        3,
        [],
        None,
        stream_gears.UploadLine.Qn,
    )



from typing import Optional


class Segment:
    """视频分段设置"""

    @staticmethod
    def by_time(time: int) -> 'Segment':
        """
        按时长分段

        :param int time: 分段时长, 单位为秒
        :return: 视频分段设置
        """
        segment = Segment()
        segment.time = time
        return segment

    @staticmethod
    def by_size(size: int) -> 'Segment':
        """
        按大小分段

        :param int size: 分段大小, 单位为字节
        :return: 视频分段设置
        """
        segment = Segment()
        segment.size = size
        return segment


class Credit:
    # FIXME: docstring
    type_id: int
    raw_text: str
    biz_id: Optional[str]
